<?php
/**
 * @version		3.4.0 administrator/components/com_buttons/helpers/buttons.php
 * 
 * @package		Buttons
 * @subpackage	com_buttons
 * @since		3.4
 *
 * @author		Helios Ciancio <info@eshiol.it>
 * @link		http://www.eshiol.it
 * @copyright	Copyright (C) 2015 Helios Ciancio. All Rights Reserved
 * @license		http://www.gnu.org/licenses/gpl-3.0.html GNU/GPL v3
 * Buttons is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 */
 
// no direct access
defined('_JEXEC') or die('Restricted access.');

use Joomla\Registry\Registry;

/**
 * Buttons helper.
 */
class ButtonsHelper
{
	static private $_extension = 'com_buttons';
	static private $_buttons = array();
	
	static function getToolbar($catid, $asset_id, $userid, $writable, $style="buttons")
	{
		JLog::add(new JLogEntry(__METHOD__,JLOG::DEBUG,self::$_extension));
		
		$db = JFactory::getDbo();
		$basepath = rtrim(JURI::root(true), '/') . '/';
	
		require_once JPATH_SITE.'/components/com_buttons/models/category.php';
		$model = JModelLegacy::getInstance('Category', 'ButtonsModel', array('ignore_request' => true));
		$model->setState('category.id', $catid);
		$model->setState('filter.c.published', 1);
		$model->setState('filter.state', 1);
		$items = $model->getItems();
		if (!$items)
		{
			return;
		}
	
		$categories = JCategories::getInstance('Buttons');
		$category = $categories->get($catid);
		$cparams = new Registry;
		$cparams->loadString($category->params);
		$toolbar_type = $cparams->get('toolbar_type');
	
		$toolbar_final = ($cparams->get('toolbar_final',0) &&
			(2 == (int)$db->setQuery(
				$db->getQuery(true)
				->select($db->qn('state'))
				->from($db->qn('#__buttons_extras'))
				->where($db->qn('catid').' = '.$catid)
				->where($db->qn('editor_user_id').' = '.$userid)
				->where($db->qn('asset_id').' = '.$asset_id)
				)->loadResult())
			);
	
		$value = (int)$db->setQuery(
			$db->getQuery(true)
			->select($db->qn('value'))
			->from($db->qn('#__buttons_extras'))
			->where($db->qn('catid').' = '.$catid)
			->where($db->qn('editor_user_id').' = '.$userid)
			->where($db->qn('asset_id').'='.$asset_id)
			)->loadResult()
			;
				
		$toolbar = new StdClass();
		$toolbar->catid=$catid;
		$toolbar->asset_id=$asset_id;
		$toolbar->toolbar_type=$toolbar_type;
		$toolbar->toolbar_final = (!$writable | $toolbar_final ? ' readonly' : '');

		// prepare toolbar
		$doc = JFactory::getDocument();
		foreach ($items as $item)
		{
			$temp = $item->images;
			$item->images = new Registry;
			$item->images->loadString($temp, 'JSON');
				
			if (!in_array($item->id, self::$_buttons))
			{
				self::$_buttons[] = $item->id;
				$doc->addStyleDeclaration(
					'.button-'.$item->id
					.'{'
					.'display:inline-block;'
					.'width:'.$item->images->get('width',32).'px;'
					.'height:'.$item->images->get('height',32).'px;'
					.'padding: 0 5px;'
					.'border:0;'
					.'background: url('.$basepath.$item->images->get('image').') no-repeat;'
					.'background-position:0px 0px;'
					.'}'
					.'.button-'.$item->id.'.active'
					.'{background-position:0px -'.(2*$item->images->get('height',32)).'px;}'
					.(!$toolbar->toolbar_final
						? '.button-'.$item->id.':hover'
						.'{background-position:0px -'.$item->images->get('height',32).'px;}'
						.'.button-'.$item->id.'.active:hover'
						.'{background-position:0px -'.$item->images->get('height',32).'px;}'
						.'.button-'.$item->id.'.pressing:hover'
						.'{background-position:0px 0px;}'
						.'.button-'.$item->id.'.active.pressing:hover'
						.'{background-position:0px -'.(2*$item->images->get('height',32)).'px;}'
						: '')
					);
			}
		}

		$toolbar->buttons = array();
		// Prepare the data.
		foreach ($items as $item)
		{
			$item->value = ((pow(2, ($item->value-1)) & $value) ? ' active' : '');
			$toolbar->buttons[$item->id] = $item;
		}
		$layout = new JLayoutFile(($writable ? 'toolbar' : $style), JPATH_SITE.'/components/com_buttons/layouts');
		return $layout->render($toolbar);
	}
	
	/**
	 * Configure the Linkbar.
	 *
	 * @param   string  $vName  The name of the active view.
	 *
	 * @return  void
	 *
	 * @since   3.4
	 */
	public static function addSubmenu($vName = 'buttons')
	{
		JHtmlSidebar::addEntry(
			JText::_('COM_BUTTONS_SUBMENU_BUTTONS'),
			'index.php?option=com_buttons&view=buttons',
			$vName == 'buttons'
		);

		JHtmlSidebar::addEntry(
			JText::_('COM_BUTTONS_SUBMENU_CATEGORIES'),
			'index.php?option=com_categories&extension=com_buttons',
			$vName == 'categories'
		);

		JHtmlSidebar::addEntry(
			JText::_('COM_BUTTONS_SUBMENU_EXTRAS'),
			'index.php?option=com_buttons&view=extras',
			$vName == 'extras'
		);
	}

	static function getReportContentIcon($row, $params)
	{
		$html = '';
		$authorisedViewLevels = JFactory::getUser()->getAuthorisedViewLevels();
		$report_access = false;
		$toolbars = ButtonsHelper::getToolbars($row);
		foreach($toolbars as $catid)
		{
			$toolbar = JTable::getInstance('Category');
			$toolbar->load($catid);
			$tparams = new Registry;
			$tparams->loadString($toolbar->params);
			$report_access = $report_access ||
			in_array($tparams->get('report_access', 3), $authorisedViewLevels);
		}
		if ($report_access)
		{
			$html = '<li class="print-icon">';
	
			$app = JFactory::getApplication();
			$input = $app->input;
			$request = $input->request;
	
			$url  = ContentHelperRoute::getArticleRoute($row->slug, $row->catid, $row->language);
			$url .= '&buttons=report';
	
			// Checks template image directory for image, if non found default are loaded
			if ($params->get('show_icons', 1))
			{
				$text = '<span class="hasTooltip icon-chart tip"></span>'.JText::_('PLG_CONTENT_BUTTONS_REPORT');
			}
			else
			{
				$text = JText::_('PLG_CONTENT_BUTTONS_REPORT');
			}
	
			$attribs['title']   = JText::_('PLG_CONTENT_BUTTONS_REPORT');
			$attribs['rel']     = 'nofollow';
	
			$html .= JHtml::_('link', JRoute::_($url), $text, $attribs);
			$html .= '</li>';
		}
		return $html;
	}


	/*
	 * where top, bottom, both
	 */
	static function getToolbars($row, $where = 'both')
	{
		$registry = new Registry;
		if (isset($row->attribs))
		{
			$registry->loadString($row->attribs);
		}
		else
		{
			return;
		}
		$arr = $registry->toArray();
		
		$toolbars = array();
		if (in_array($where, array('top', 'both')))
		{
			if (isset($arr['toolbar-top']))
			{
				$toolbars = array_merge($toolbars, $arr['toolbar-top']);
			}
			$parent_id = $row->catid;
			while ($parent_id)
			{
				$category = JTable::getInstance('Category');
				$category->load($parent_id);
				$cparams = new Registry;
				$cparams->loadString($category->params);
				$carr = $cparams->toArray();
				if (isset($carr['toolbar-top']))
				{
					$toolbars = array_merge($toolbars, $carr['toolbar-top']);
				}
				$parent_id = $category->parent_id;
			}
		}
		
		if (in_array($where, array('bottom', 'both')))
		{
			if (isset($arr['toolbar-bottom']))
			{
				$toolbars = array_merge($toolbars, $arr['toolbar-bottom']);
			}
			$parent_id = $row->catid;
			while ($parent_id)
			{
				$category = JTable::getInstance('Category');
				$category->load($parent_id);
				$cparams = new Registry;
				$cparams->loadString($category->params);
				$carr = $cparams->toArray();
				if (isset($carr['toolbar-bottom']))
				{
					$toolbars = array_merge($toolbars, $carr['toolbar-bottom']);
				}
				$parent_id = $category->parent_id;
			}
		}
		$toolbars = array_unique($toolbars);
		
		return $toolbars;
	}
}
